@@ -15,7 +15,7 @@
 #define PRACTICE_MAINWINDOW_H
 
 #include <KXmlGuiWindow>
-#include <QtGui/QKeyEvent>
+#include <QKeyEvent>
 #include "sessionmanagerbase.h"
 
 class ParleyMainWindow;
@@ -32,7 +32,7 @@ class PracticeMainWindow : public KXmlGuiWindow
 {
     Q_OBJECT
 public:
-    PracticeMainWindow(SessionManagerBase* sessionManager, ParleyMainWindow* mainWindow = 0);
+    explicit PracticeMainWindow(SessionManagerBase* sessionManager, ParleyMainWindow* mainWindow = 0);
     ~PracticeMainWindow();
 
     void startPractice();
